Hashing

Enum Hashing 

pub enum Hashing {
    Sha1,
    Sha256,
    Sha384,
    Sha512,
    Sha512_256,
}
The hashing algorithm. SHA-1 and SHA-2 algorithms are supported.

Variants



Sha1

The SHA-1 hash algorithm. Should generally be avoided unless working with legacy software.



Sha256

The SHA-2 256 bit hash algorithm.



Sha384

The SHA-2 384 bit hash algorithm.



Sha512

The SHA-2 512 bit hash algorithm.



Sha512_256

The SHA-2 512_256 bit hash algorithm. Uses SHA-512 but returns only 256 bits.

Implementations

Source

impl Hashing

pub fn new_context(&self) -> HashContext

Creates a new instance of a HashContext to be used with the selected Hashing algorithm.

pub fn hash(&self, data: &[u8]) -> Hash

Returns a Hash of the given byte array data.

pub fn hash_vec(&self, data: Vec<u8>) -> Hash

Returns a Hash of the given byte vector data.

pub fn hash_str(&self, data: &str) -> Hash

Returns a Hash of the given string data.

pub fn hash_file(&self, path: &str) -> Result<Hash, Error>

Returns a Result<Hash, Error> containing the Hash of the file located at the given path on success, otherwise returns a std::io::Error if the file doesn’t exist or can’t be opened in read-only mode.